@@ -133,6 +133,7 @@ mod l2_orderbook {
     use chrono::prelude::*;
     use crypto_market_type::MarketType;
     use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_type::MessageType;
 
     #[test]
     fn spot_snapshot() {
@@ -152,6 +153,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "bitfinex",
             MarketType::Spot,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("bitfinex", MarketType::Spot, raw_msg).unwrap(),
             orderbook,
@@ -193,6 +195,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "bitfinex",
             MarketType::Spot,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("bitfinex", MarketType::Spot, raw_msg).unwrap(),
             orderbook,
@@ -221,6 +224,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "bitfinex",
             MarketType::LinearSwap,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("bitfinex", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
@@ -266,6 +270,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "bitfinex",
             MarketType::LinearSwap,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("bitfinex", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
