@@ -131,6 +131,7 @@ mod funding_rate {
 mod l2_orderbook {
     use crypto_market_type::MarketType;
     use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_type::MessageType;
     use float_cmp::approx_eq;
 
     #[test]
@@ -145,6 +146,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "bitget",
             MarketType::LinearSwap,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("bitget", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
@@ -226,6 +228,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "bitget",
             MarketType::LinearSwap,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("bitget", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
@@ -292,6 +295,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "bitget",
             MarketType::InverseSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("bitget", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
@@ -333,6 +337,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "bitget",
             MarketType::InverseSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("bitget", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
