@@ -109,6 +109,7 @@ mod trade {
 mod l2_orderbook {
     use crypto_market_type::MarketType;
     use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_type::MessageType;
 
     #[test]
     fn inverse_future_snapshot() {
@@ -122,6 +123,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "deribit",
             MarketType::InverseFuture,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("deribit", MarketType::InverseFuture, raw_msg).unwrap(),
             orderbook,
@@ -184,6 +186,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "deribit",
             MarketType::InverseSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("deribit", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
@@ -245,6 +248,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "deribit",
             MarketType::InverseSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("deribit", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
@@ -307,6 +311,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "deribit",
             MarketType::InverseSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("deribit", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
@@ -359,6 +364,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "deribit",
             MarketType::EuropeanOption,
+            MessageType::L2Event,
             "BTC/BTC".to_string(),
             extract_symbol("deribit", MarketType::EuropeanOption, raw_msg).unwrap(),
             orderbook,
