@@ -31,6 +31,7 @@ mod trade {
 mod l2_orderbook {
     use crypto_market_type::MarketType;
     use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_type::MessageType;
 
     #[test]
     fn linear_swap() {
@@ -45,6 +46,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "dydx",
             MarketType::LinearSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("dydx", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
@@ -84,6 +86,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "dydx",
             MarketType::LinearSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("dydx", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
