@@ -112,6 +112,7 @@ mod trade {
 mod l2_orderbook {
     use crypto_market_type::MarketType;
     use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_type::MessageType;
 
     #[test]
     fn spot_update() {
@@ -128,6 +129,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "kucoin",
             MarketType::Spot,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("kucoin", MarketType::Spot, raw_msg).unwrap(),
             orderbook,
@@ -151,6 +153,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "kucoin",
             MarketType::InverseSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("kucoin", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
@@ -178,6 +181,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "kucoin",
             MarketType::LinearSwap,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("kucoin", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
@@ -205,6 +209,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "kucoin",
             MarketType::InverseFuture,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("kucoin", MarketType::InverseFuture, raw_msg).unwrap(),
             orderbook,
