@@ -96,6 +96,7 @@ mod trade {
 mod l2_orderbook {
     use crypto_market_type::MarketType;
     use crypto_msg_parser::{extract_symbol, parse_l2};
+    use crypto_msg_type::MessageType;
 
     #[test]
     fn spot_snapshot() {
@@ -109,6 +110,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "zbg",
             MarketType::Spot,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("zbg", MarketType::Spot, raw_msg).unwrap(),
             orderbook,
@@ -138,6 +140,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "zbg",
             MarketType::Spot,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("zbg", MarketType::Spot, raw_msg).unwrap(),
             orderbook,
@@ -163,6 +166,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "zbg",
             MarketType::LinearSwap,
+            MessageType::L2Event,
             "BTC/USDT".to_string(),
             extract_symbol("zbg", MarketType::LinearSwap, raw_msg).unwrap(),
             orderbook,
@@ -194,6 +198,7 @@ mod l2_orderbook {
         crate::utils::check_orderbook_fields(
             "zbg",
             MarketType::InverseSwap,
+            MessageType::L2Event,
             "BTC/USD".to_string(),
             extract_symbol("zbg", MarketType::InverseSwap, raw_msg).unwrap(),
             orderbook,
